@@ -5,6 +5,7 @@ gjamTrimY <- function(y, minObs = 2, maxCols = NULL, OTHER = TRUE){
     # maxCols   - number of columns to retain, those with highest values
     # OTHER     - logical or names to include in 'other' class
     # if(OTHER) sum of rare are returned in 'other' column
+    # if already a column 'other', they combined
     
     y      <- as.matrix(y)
     nc     <- ncol(y)
@@ -37,6 +38,11 @@ gjamTrimY <- function(y, minObs = 2, maxCols = NULL, OTHER = TRUE){
       other  <- rowSums(cbind(other,y[,-ww]),na.rm=T)
       out    <- cbind(out,other)
       mnames <- c(mnames,'other')
+      ww <- which(colnames(out) == 'other')
+      if(length(ww) > 1){
+        other <- rowSums(out[,ww])
+        out <- cbind(out[,-ww],other)
+      }
     }
     
     if(!is.matrix(out)){
